@@ -28,7 +28,7 @@ dependencies using raw pip. The virtual environment is not created, but one can
 issue `python3 -m venv venv/ && . venv/bin/activate` to create one.
 """
 
-__version__ = "1.4.5"
+__version__ = "1.4.6"
 __author__ = "Fridolin Pokorny <fridex.devel@gmail.com>"
 __title__ = "micropipenv"
 
@@ -48,7 +48,7 @@ from pathlib import Path
 from urllib.parse import urlparse
 
 _LOGGER = logging.getLogger(__title__)
-_SUPPORTED_PIP_STR = ">=9,<=22.3.1"  # Respects requirement in setup.py and latest pip to release date.
+_SUPPORTED_PIP_STR = ">=9,<=23.0.1"  # Respects requirement in setup.py and latest pip to release date.
 
 try:
     from pip import __version__ as pip_version
@@ -184,7 +184,7 @@ def _check_pip_version(raise_on_incompatible=False):  # type: (bool) -> bool
 
 
 def _import_toml():  # type: () -> Any
-    """Import and return toml or pytoml module (in this order)."""
+    """Import and return tomllib, toml, pytoml, or tomli module (in this order)."""
     exception_names = {
         "tomllib": "TOMLDecodeError",
         "toml": "TomlDecodeError",
@@ -1061,15 +1061,7 @@ def _parse_pipfile_dependency_info(pipfile_entry):  # type: (Union[str, Dict[str
     if isinstance(pipfile_entry, str):
         return {"version": pipfile_entry}
     elif isinstance(pipfile_entry, dict):
-        result = {"version": pipfile_entry["version"]}
-
-        if pipfile_entry.get("extras"):
-            result["extras"] = pipfile_entry["extras"]
-
-        if pipfile_entry.get("markers"):
-            result["markers"] = pipfile_entry["markers"]
-
-        return result
+        return pipfile_entry
 
     raise ValueError("Unknown entry in Pipfile (should be of type dict or a str): {}".format(pipfile_entry))
 
